@@ -5,21 +5,29 @@ test_that("demean works", {
   df$ID <- sample(1:4, nrow(df), replace = TRUE) # fake-ID
 
   set.seed(123)
-  df$binary <- as.factor(rbinom(150, 1, .35)) # binary variable
+  df$binary <- as.factor(rbinom(150, 1, 0.35)) # binary variable
 
   set.seed(123)
   x <- demean(df, select = c("Sepal.Length", "Petal.Length"), group = "ID")
   expect_snapshot(head(x))
 
   set.seed(123)
-  x <- demean(df, select = c("Sepal.Length", "binary", "Species"), group = "ID")
+  expect_message(
+    x <- demean(df, select = c("Sepal.Length", "binary", "Species"), group = "ID"),
+    "have been coerced to numeric"
+  )
   expect_snapshot(head(x))
 
   set.seed(123)
-  expect_equal(
-    demean(df, select = ~ Sepal.Length + binary + Species, group = ~ID),
-    demean(df, select = c("Sepal.Length", "binary", "Species"), group = "ID")
+  expect_message(
+    y <- demean(df, select = ~ Sepal.Length + binary + Species, group = ~ID),
+    "have been coerced to numeric"
   )
+  expect_message(
+    z <- demean(df, select = c("Sepal.Length", "binary", "Species"), group = "ID"),
+    "have been coerced to numeric"
+  )
+  expect_identical(y, z)
 })
 
 test_that("demean interaction term", {
@@ -44,7 +52,7 @@ test_that("demean shows message if some vars don't exist", {
 
   set.seed(123)
   expect_message(
-    demean(dat, select = c("foo"), group = "ID"),
+    demean(dat, select = "foo", group = "ID"),
     regexp = "not found"
   )
 })
